==> zio-aws-amplifybackend_2.13-6.20.78.3-sources.jar: zio/aws/amplifybackend/model/RemoveBackendConfigResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class RemoveBackendConfigResponse(
    error: Optional[__string] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse = {
    import RemoveBackendConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
      .builder()
      .optionallyWith(error.map(value => value: java.lang.String))(_.error)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly =
    zio.aws.amplifybackend.model.RemoveBackendConfigResponse
      .wrap(buildAwsValue())
}
object RemoveBackendConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.RemoveBackendConfigResponse =
      zio.aws.amplifybackend.model
        .RemoveBackendConfigResponse(error.map(value => value))
    def error: Optional[__string]
    def getError: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("error", error)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ) extends zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly {
    override val error: Optional[__string] = zio.aws.core.internal
      .optionalFromNullable(impl.error())
      .map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ): zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-amplifybackend_3-5.17.124.3-sources.jar: zio/aws/amplifybackend/model/RemoveBackendConfigResponse.scala <==
package zio.aws.amplifybackend.model
import zio.aws.amplifybackend.model.primitives.__string
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class RemoveBackendConfigResponse(error: Option[__string] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse = {
    import RemoveBackendConfigResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
      .builder()
      .optionallyWith(
        error.map(value => __string.unwrap(value): java.lang.String)
      )(_.error)
      .build()
  }
  def asReadOnly
      : zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly =
    zio.aws.amplifybackend.model.RemoveBackendConfigResponse
      .wrap(buildAwsValue())
}
object RemoveBackendConfigResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.amplifybackend.model.RemoveBackendConfigResponse =
      zio.aws.amplifybackend.model
        .RemoveBackendConfigResponse(error.map(value => value))
    def error: Option[__string]
    def getError: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("error", error)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ) extends zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly {
    override val error: Option[__string] = scala
      .Option(impl.error())
      .map(value => zio.aws.amplifybackend.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.amplifybackend.model.RemoveBackendConfigResponse
  ): zio.aws.amplifybackend.model.RemoveBackendConfigResponse.ReadOnly =
    new Wrapper(impl)
}
